==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/typescript/Projenrc.java <==
package io.github.cdklabs.projen.typescript;

/**
 * (experimental) Sets up a typescript project to use TypeScript for projenrc.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.931Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.typescript.Projenrc")
public class Projenrc extends io.github.cdklabs.projen.Component {

    protected Projenrc(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projenrc(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.typescript.TypeScriptProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.typescript.ProjenrcOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.typescript.TypeScriptProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.typescript.Projenrc}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.typescript.Projenrc> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.typescript.TypeScriptProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.typescript.TypeScriptProject project;
        private io.github.cdklabs.projen.typescript.ProjenrcOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.typescript.TypeScriptProject project) {
            this.project = project;
        }

        /**
         * (experimental) The name of the projenrc file.
         * <p>
         * Default: ".projenrc.ts"
         * <p>
         * @return {@code this}
         * @param filename The name of the projenrc file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(final java.lang.String filename) {
            this.options().filename(filename);
            return this;
        }

        /**
         * (experimental) A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file.
         * <p>
         * Default: "projenrc"
         * <p>
         * @return {@code this}
         * @param projenCodeDir A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenCodeDir(final java.lang.String projenCodeDir) {
            this.options().projenCodeDir(projenCodeDir);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.typescript.Projenrc}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.typescript.Projenrc build() {
            return new io.github.cdklabs.projen.typescript.Projenrc(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.typescript.ProjenrcOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.typescript.ProjenrcOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/typescript/Projenrc.java <==
package io.github.cdklabs.projen.typescript;

/**
 * (experimental) Sets up a typescript project to use TypeScript for projenrc.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.600Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.typescript.Projenrc")
public class Projenrc extends io.github.cdklabs.projen.ProjenrcFile {

    protected Projenrc(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Projenrc(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.typescript.TypeScriptProject project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.typescript.ProjenrcOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), options });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Projenrc(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.typescript.TypeScriptProject project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Called before synthesis.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    public void preSynthesize() {
        software.amazon.jsii.Kernel.call(this, "preSynthesize", software.amazon.jsii.NativeType.VOID);
    }

    /**
     * (experimental) The path of the projenrc file.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFilePath() {
        return software.amazon.jsii.Kernel.get(this, "filePath", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.typescript.Projenrc}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.typescript.Projenrc> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.typescript.TypeScriptProject project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.typescript.TypeScriptProject project;
        private io.github.cdklabs.projen.typescript.ProjenrcOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.typescript.TypeScriptProject project) {
            this.project = project;
        }

        /**
         * (experimental) The name of the projenrc file.
         * <p>
         * Default: ".projenrc.ts"
         * <p>
         * @return {@code this}
         * @param filename The name of the projenrc file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder filename(final java.lang.String filename) {
            this.options().filename(filename);
            return this;
        }

        /**
         * (experimental) A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file.
         * <p>
         * Default: "projenrc"
         * <p>
         * @return {@code this}
         * @param projenCodeDir A directory tree that may contain *.ts files that can be referenced from your projenrc typescript file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder projenCodeDir(final java.lang.String projenCodeDir) {
            this.options().projenCodeDir(projenCodeDir);
            return this;
        }

        /**
         * (experimental) Whether to use <code>SWC</code> for ts-node.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param swc Whether to use <code>SWC</code> for ts-node. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder swc(final java.lang.Boolean swc) {
            this.options().swc(swc);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.typescript.Projenrc}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.typescript.Projenrc build() {
            return new io.github.cdklabs.projen.typescript.Projenrc(
                this.project,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.typescript.ProjenrcOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.typescript.ProjenrcOptions.Builder();
            }
            return this.options;
        }
    }
}
